@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2022 the orix developers
+# Copyright 2018-2023 the orix developers
 #
 # This file is part of orix.
 #
@@ -18,14 +18,12 @@
 
 import copy
 from typing import Optional, Tuple, Union
-import warnings
 
 import matplotlib.pyplot as plt
 import numpy as np
 
-from orix._util import deprecated, deprecated_argument
 from orix.crystal_map.crystal_map_properties import CrystalMapProperties
-from orix.crystal_map.phase_list import Phase, PhaseList
+from orix.crystal_map.phase_list import ALL_COLORS, Phase, PhaseList
 from orix.quaternion import Orientation, Rotation
 
 
@@ -52,18 +50,6 @@ class CrystalMap:
     y
         Map y coordinate of each data point. If not given, the map is
         assumed to be 1D, and it is set to ``None``.
-    z
-        Map z coordinate of each data point. If not given, the map is
-        assumed to be 2D or 1D, and it is set to ``None``.
-
-        .. deprecated:: 0.10.1
-
-            Will be removed in 0.11.0. Support for 3D crystal maps is
-            minimal and brittle, and it was therefore decided to remove
-            it altogether. If you rely on this functionality, please
-            report it in an issue at
-            https://github.com/pyxem/orix/issues.
-
     phase_list
         A list of phases in the data with their with names, space
         groups, point groups, and structures. The order in which the
@@ -131,7 +117,7 @@ class CrystalMap:
     :mod:`~orix.data` module
 
     >>> from orix import data
-    >>> xmap = data.sdss_ferrite_austenite()
+    >>> xmap = data.sdss_ferrite_austenite(allow_download=True)
     >>> xmap
     Phase   Orientations       Name  Space group  Point group  Proper point group       Color
         1   5657 (48.4%)  austenite         None          432                 432    tab:blue
@@ -217,14 +203,12 @@ class CrystalMap:
     Scan unit: um
     """
 
-    @deprecated_argument(name="z", since="0.10.1", removal="0.11.0")
     def __init__(
         self,
         rotations: Rotation,
         phase_id: Optional[np.ndarray] = None,
         x: Optional[np.ndarray] = None,
         y: Optional[np.ndarray] = None,
-        z: Optional[np.ndarray] = None,
         phase_list: Optional[PhaseList] = None,
         prop: Optional[dict] = None,
         scan_unit: Optional[str] = "px",
@@ -251,11 +235,10 @@ class CrystalMap:
         self._id = point_id
 
         # Set spatial coordinates
-        if x is None and y is None and z is None:
+        if x is None and y is None:
             x = np.arange(data_size)
         self._x = x
         self._y = y
-        self._z = z
 
         # Create phase list
         # Sorted in ascending order
@@ -268,7 +251,7 @@ class CrystalMap:
         if phase_list is None:
             self._phases = PhaseList(ids=unique_phase_ids)
         else:
-            phase_list = copy.deepcopy(phase_list)
+            phase_list = phase_list.deepcopy()
             phase_ids = phase_list.ids
             n_different = len(phase_ids) - len(unique_phase_ids)
             if n_different > 0:
@@ -282,15 +265,20 @@ class CrystalMap:
                         break
             elif n_different < 0:
                 # Create new phase list adding the missing phases with
-                # default initial values
-                phase_list = PhaseList(
-                    names=phase_list.names,
-                    space_groups=phase_list.space_groups,
-                    point_groups=phase_list.point_groups,
-                    colors=phase_list.colors,
-                    structures=phase_list.structures,
-                    ids=unique_phase_ids,
+                # default initial values (but unique colors)
+                phase_dict = {}
+                all_colors = list(ALL_COLORS.keys())
+                all_unique_colors = np.delete(
+                    all_colors, np.isin(all_colors, phase_list.colors)
                 )
+                ci = 0
+                for i in unique_phase_ids:
+                    if i in phase_ids:
+                        phase_dict[i] = phase_list[i]
+                    else:
+                        phase_dict[i] = Phase(color=all_unique_colors[ci])
+                        ci += 1
+                phase_list = PhaseList(phase_dict)
             # Ensure phase list IDs correspond to IDs in phase_id array
             new_ids = list(unique_phase_ids.astype(int))
             phase_list._dict = dict(zip(new_ids, phase_list._dict.values()))
@@ -347,7 +335,7 @@ class CrystalMap:
     def x(self) -> Union[None, np.ndarray]:
         """Return the x coordinates of points in data."""
         if self._x is None or len(np.unique(self._x)) == 1:
-            return None
+            return
         else:
             return self._x[self.is_in_data]
 
@@ -355,19 +343,10 @@ class CrystalMap:
     def y(self) -> Union[None, np.ndarray]:
         """Return the y coordinates of points in data."""
         if self._y is None or len(np.unique(self._y)) == 1:
-            return None
+            return
         else:
             return self._y[self.is_in_data]
 
-    @property
-    @deprecated(since="0.10.1", removal="0.11.0", object_type="property")
-    def z(self) -> Union[None, np.ndarray]:
-        """Return the z coordinates of points in data."""
-        if self._z is None or len(np.unique(self._z)) == 1:
-            return None
-        else:
-            return self._z[self.is_in_data]
-
     @property
     def dx(self) -> float:
         """Return the x coordinate step size."""
@@ -379,10 +358,56 @@ class CrystalMap:
         return self._step_size_from_coordinates(self._y)
 
     @property
-    @deprecated(since="0.10.1", removal="0.11.0", object_type="property")
-    def dz(self) -> float:
-        """Return the z coordiante step size."""
-        return self._step_size_from_coordinates(self._z)
+    def row(self) -> Union[None, np.ndarray]:
+        """Return the row coordinate of each point in the data.
+
+        Returns ``None`` if :attr:`z` is not ``None``.
+
+        Examples
+        --------
+        >>> from orix.crystal_map import CrystalMap
+        >>> xmap = CrystalMap.empty((3, 4))
+        >>> xmap.row
+        array([0, 0, 0, 0, 1, 1, 1, 1, 2, 2, 2, 2])
+        >>> xmap[1:3, 1:3].row
+        array([0, 0, 1, 1])
+        """
+        orig_shape = self._original_shape
+        if len(orig_shape) == 1:
+            if self.x is None:
+                orig_shape += (1,)
+            else:
+                orig_shape = (1,) + orig_shape
+        rows, _ = np.indices(orig_shape)
+        rows = rows.flatten()[self.is_in_data]
+        rows -= rows.min()
+        return rows
+
+    @property
+    def col(self) -> Union[None, np.ndarray]:
+        """Return the column coordinate of each point in the data.
+
+        Returns ``None`` if :attr:`z` is not ``None``.
+
+        Examples
+        --------
+        >>> from orix.crystal_map import CrystalMap
+        >>> xmap = CrystalMap.empty((3, 4))
+        >>> xmap.col
+        array([0, 1, 2, 3, 0, 1, 2, 3, 0, 1, 2, 3])
+        >>> xmap[1:3, 1:3].col
+        array([0, 1, 0, 1])
+        """
+        shape = self._original_shape
+        if len(shape) == 1:
+            if self.x is None:
+                shape += (1,)
+            else:
+                shape = (1,) + shape
+        _, cols = np.indices(shape)
+        cols = cols.flatten()[self.is_in_data]
+        cols -= cols.min()
+        return cols
 
     @property
     def phase_id(self) -> np.ndarray:
@@ -487,7 +512,7 @@ class CrystalMap:
         Examples
         --------
         >>> from orix import data
-        >>> xmap = data.sdss_ferrite_austenite()
+        >>> xmap = data.sdss_ferrite_austenite(allow_download=True)
         >>> xmap
         Phase   Orientations       Name  Space group  Point group  Proper point group       Color
             1   5657 (48.4%)  austenite         None          432                 432    tab:blue
@@ -543,31 +568,17 @@ class CrystalMap:
     @property
     def _coordinates(self) -> dict:
         """Return the coordinates of points in the data."""
-        # TODO: Make this "dynamic"/dependable when enabling specimen
-        #  reference frame
-
-        # TODO: Remove after (any) one release after 0.10.1
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore", "Property ", np.VisibleDeprecationWarning)
-            return {"z": self.z, "y": self.y, "x": self.x}
+        return {"y": self.y, "x": self.x}
 
     @property
     def _all_coordinates(self) -> dict:
         """Return the coordinates of all points."""
-        # TODO: Make this "dynamic"/dependable when enabling specimen
-        #  reference frame
-        return {"z": self._z, "y": self._y, "x": self._x}
+        return {"y": self._y, "x": self._x}
 
     @property
     def _step_sizes(self) -> dict:
         """Return the step sizes of dimensions in the data."""
-        # TODO: Make this "dynamic"/dependable when enabling specimen
-        #  reference frame
-
-        # TODO: Remove after (any) one release after 0.10.1
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore", "Property ", np.VisibleDeprecationWarning)
-            return {"z": self.dz, "y": self.dy, "x": self.dx}
+        return {"y": self.dy, "x": self.dx}
 
     @property
     def _coordinate_axes(self) -> dict:
@@ -748,7 +759,7 @@ class CrystalMap:
         shape: Union[None, int, tuple] = None,
         step_sizes: Union[None, int, tuple] = None,
     ) -> "CrystalMap":
-        """Return a crystal map of a given shape and step sizes with
+        """Return a crystal map of a given 2D shape and step sizes with
         identity rotations.
 
         Parameters
@@ -756,29 +767,10 @@ class CrystalMap:
         shape
             Map shape. Default is a 2D map of shape (5, 10), i.e. with
             five rows and ten columns.
-
-            .. deprecated:: 0.10.1
-
-            Returning coordinates for a 3D map is deprecated, and this
-            method will only support 1D or 2D maps in 0.11.0. Support
-            for 3D crystal maps is minimal and brittle, and it was
-            therefore decided to remove it altogether. If you rely on
-            this functionality, please report it in an issue at
-            https://github.com/pyxem/orix/issues.
-
         step_sizes
             Map step sizes. If not given, it is set to 1 px in each map
             direction given by ``shape``.
 
-            .. deprecated:: 0.10.1
-
-            Returning coordinates for a 3D map is deprecated, and this
-            method will only support 1D or 2D maps in 0.11.0. Support
-            for 3D crystal maps is minimal and brittle, and it was
-            therefore decided to remove it altogether. If you rely on
-            this functionality, please report it in an issue at
-            https://github.com/pyxem/orix/issues.
-
         Returns
         -------
         xmap
@@ -839,7 +831,7 @@ class CrystalMap:
         Examples
         --------
         >>> from orix import data
-        >>> xmap = data.sdss_ferrite_austenite()
+        >>> xmap = data.sdss_ferrite_austenite(allow_download=True)
         >>> xmap
         Phase   Orientations       Name  Space group  Point group  Proper point group       Color
             1   5657 (48.4%)  austenite         None          432                 432    tab:blue
@@ -892,8 +884,6 @@ class CrystalMap:
                 array[self.is_in_data] = rotations.to_euler()
             else:  # item == "orientations"
                 # Fill in orientations per phase
-                # TODO: Consider whether orientations should be calculated
-                #  upon loading
                 for i, _ in self.phases_in_data:
                     phase_mask = (self._phase_id == i) * self.is_in_data
                     phase_mask_in_data = self.phase_id == i
@@ -1013,7 +1003,7 @@ class CrystalMap:
         Examples
         --------
         >>> from orix import data
-        >>> xmap = data.sdss_ferrite_austenite()
+        >>> xmap = data.sdss_ferrite_austenite(allow_download=True)
         >>> xmap
         Phase   Orientations       Name  Space group  Point group  Proper point group       Color
             1   5657 (48.4%)  austenite         None          432                 432    tab:blue
@@ -1144,29 +1134,10 @@ def create_coordinate_arrays(
     shape
         Map shape. Default is a 2D map of shape (5, 10) with five rows
         and ten columns.
-
-        .. deprecated:: 0.10.1
-
-            Returning coordinates for a 3D map is deprecated, and this
-            method will only support 1D or 2D maps in 0.11.0. Support
-            for 3D crystal maps is minimal and brittle, and it was
-            therefore decided to remove it altogether. If you rely on
-            this functionality, please report it in an issue at
-            https://github.com/pyxem/orix/issues.
-
     step_sizes
         Map step sizes. If not given, it is set to 1 px in each map
         direction given by ``shape``.
 
-        .. deprecated:: 0.10.1
-
-            Returning coordinates for a 3D map is deprecated, and this
-            method will only support 1D or 2D maps in 0.11.0. Support
-            for 3D crystal maps is minimal and brittle, and it was
-            therefore decided to remove it altogether. If you rely on
-            this functionality, please report it in an issue at
-            https://github.com/pyxem/orix/issues.
-
     Returns
     -------
     d
@@ -1191,30 +1162,19 @@ def create_coordinate_arrays(
     if step_sizes is None:
         step_sizes = (1,) * ndim
 
-    # TODO: Remove after (any) one release after 0.10.1
-    if ndim == 3:
-        warnings.warn(
-            "Returning coordinates for a 3D map is deprecated, and this function will "
-            "only support 1D or 2D maps in 0.11.0. Support for 3D crystal maps is "
-            "minimal and brittle, and it was therefore decided to remove it altogether."
-            " If you rely on this functionality, please report it in an issue at "
-            "https://github.com/pyxem/orix/issues",
-            np.VisibleDeprecationWarning,
-        )
+    if ndim == 3 or len(step_sizes) > 2:
+        raise ValueError("Can only create coordinate arrays for 2D maps")
 
-    # Set up as if a 3D map is to be returned
-    dz, dy, dx = (1,) * (3 - ndim) + step_sizes
-    nz, ny, nx = (1,) * (3 - ndim) + shape
+    # Set up as if a 2D map is to be returned
+    dy, dx = (1,) * (2 - ndim) + step_sizes
+    ny, nx = (1,) * (2 - ndim) + shape
     d = dict()
 
     # Add coordinate arrays depending on the number of map dimensions
-    d["x"] = np.tile(np.arange(nx) * dx, ny * nz).flatten()
+    d["x"] = np.tile(np.arange(nx) * dx, ny).flatten()
     map_size = nx
     if ndim > 1:
-        d["y"] = np.tile(np.sort(np.tile(np.arange(ny) * dy, nx)), nz).flatten()
+        d["y"] = np.sort(np.tile(np.arange(ny) * dy, nx)).flatten()
         map_size *= ny
-    if ndim > 2:
-        d["z"] = np.array([np.ones(ny * nx) * i * dz for i in range(nz)]).flatten()
-        map_size *= nz
 
     return d, map_size
