@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2022 the orix developers
+# Copyright 2018-2023 the orix developers
 #
 # This file is part of orix.
 #
@@ -476,7 +476,7 @@ class Symmetry(Rotation):
             default marker style for reprojected vectors is "+". Values
             used for vector(s) on the visible hemisphere are used unless
             another value is passed here.
-        kwargs
+        **kwargs
             Keyword arguments passed to
             :meth:`~orix.plot.StereographicPlot.scatter`, which passes
             these on to :meth:`matplotlib.axes.Axes.scatter`.
