@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2022 the orix developers
+# Copyright 2018-2023 the orix developers
 #
 # This file is part of orix.
 #
@@ -16,17 +16,19 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
+import warnings
+
 import numpy as np
 import pytest
 
-from orix._util import deprecated
+from orix._util import deprecated, deprecated_argument
 
 
-class TestDeprecationWarning:
+class TestDeprecateFunctionOrProperty:
     def test_deprecation_since(self):
-        """Ensure functions decorated with the custom deprecated
-        decorator returns desired output, raises a desired warning, and
-        gets the desired additions to their docstring.
+        """Functions decorated with the custom deprecated decorator
+        returns desired output, raises a desired warning, and gets the
+        desired additions to their docstring.
         """
 
         class Foo:
@@ -35,7 +37,7 @@ class TestDeprecationWarning:
                 since="1.3",
                 alternative="bar_prop2",
                 removal="1.4",
-                object_type="not a function",
+                object_type="property",
             )
             def bar_prop(self):
                 return 1
@@ -96,3 +98,45 @@ class TestDeprecationWarning:
             ".. deprecated:: 1.3\n"
             f"   {desired_msg3}"
         )
+
+
+class TestDeprecateArgument:
+    def test_deprecate_argument(self):
+        """Functions decorated with the custom `deprecated_argument`
+        decorator returns desired output and raises a desired warning
+        only if the argument is passed.
+        """
+
+        class Foo:
+            @deprecated_argument(name="a", since="1.3", removal="1.4")
+            def bar_arg(self, **kwargs):
+                return kwargs
+
+            @deprecated_argument(name="a", since="1.3", removal="1.4", alternative="b")
+            def bar_arg_alt(self, **kwargs):
+                return kwargs
+
+        my_foo = Foo()
+
+        # Does not warn
+        with warnings.catch_warnings():
+            warnings.simplefilter("error")
+            assert my_foo.bar_arg(b=1) == {"b": 1}
+
+        # Warns
+        with pytest.warns(np.VisibleDeprecationWarning) as record2:
+            assert my_foo.bar_arg(a=2) == {"a": 2}
+        assert str(record2[0].message) == (
+            r"Argument `a` is deprecated and will be removed in version 1.4. "
+            r"To avoid this warning, please do not use `a`. See the documentation of "
+            r"`bar_arg()` for more details."
+        )
+
+        # Warns with alternative
+        with pytest.warns(np.VisibleDeprecationWarning) as record3:
+            assert my_foo.bar_arg_alt(a=3) == {"a": 3}
+        assert str(record3[0].message) == (
+            r"Argument `a` is deprecated and will be removed in version 1.4. "
+            r"To avoid this warning, please do not use `a`. Use `b` instead. See the "
+            r"documentation of `bar_arg_alt()` for more details."
+        )
