@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2022 the orix developers
+# Copyright 2018-2023 the orix developers
 #
 # This file is part of orix.
 #
@@ -384,7 +384,7 @@ class Vector3d(Object3d):
         return dots
 
     def cross(self, other: Vector3d) -> Vector3d:
-        """The cross product of a vector with another vector.
+        """Return the cross product of a vector with another vector.
 
         Vectors must have compatible shape for broadcasting to work.
 
@@ -407,20 +407,28 @@ class Vector3d(Object3d):
 
     @classmethod
     def from_polar(
-        cls, azimuth: np.ndarray, polar: np.ndarray, radial: float = 1.0
+        cls,
+        azimuth: Union[np.ndarray, list, tuple, float],
+        polar: Union[np.ndarray, list, tuple, float],
+        radial: float = 1.0,
+        degrees: bool = False,
     ) -> Vector3d:
-        """Create a :class:`Vector3d` from spherical coordinates
-        according to the ISO 31-11 standard
-        :cite:`weisstein2005spherical`.
+        """Initialize from spherical coordinates according to the ISO
+        31-11 standard :cite:`weisstein2005spherical`.
 
         Parameters
         ----------
         azimuth
-            The azimuth angle, in radians.
+            Azimuth angle(s) in radians (``degrees=False``) or degrees
+            (``degrees=True``).
         polar
-            The polar angle, in radians.
+            Polar angle(s) in radians (``degrees=False``) or degrees
+            (``degrees=True``).
         radial
-            The radial distance. Defaults to 1 to produce unit vectors.
+            Radial distance. Defaults to 1 to produce unit vectors.
+        degrees
+            If ``True``, the angles are assumed to be in degrees.
+            Default is ``False``.
 
         Returns
         -------
@@ -428,6 +436,9 @@ class Vector3d(Object3d):
         """
         azimuth = np.atleast_1d(azimuth)
         polar = np.atleast_1d(polar)
+        if degrees:
+            azimuth = np.deg2rad(azimuth)
+            polar = np.deg2rad(polar)
         sin_polar = np.sin(polar)
         x = np.cos(azimuth) * sin_polar
         y = np.sin(azimuth) * sin_polar
@@ -465,8 +476,8 @@ class Vector3d(Object3d):
         """Return a unit vector in the z-direction."""
         return cls((0, 0, 1))
 
-    def angle_with(self, other: Vector3d) -> np.ndarray:
-        """Calculate the angles between these vectors in other vectors.
+    def angle_with(self, other: Vector3d, degrees: bool = False) -> np.ndarray:
+        """Return the angles between these vectors in other vectors.
 
         Vectors must have compatible shapes for broadcasting to work.
 
@@ -474,14 +485,21 @@ class Vector3d(Object3d):
         ----------
         other
             Another vector.
+        degrees
+            If ``True``, the given angles are returned in degrees.
+            Default is ``False``.
 
         Returns
         -------
         angles
-            The angle between the vectors, in radians.
+            Angles in radians (``degrees=False``)  or degrees
+            (``degrees=True``).
         """
         cosines = np.round(self.dot(other) / self.norm / other.norm, 10)
-        return np.arccos(cosines)
+        angles = np.arccos(cosines)
+        if degrees:
+            angles = np.rad2deg(angles)
+        return angles
 
     def rotate(
         self,
@@ -589,22 +607,36 @@ class Vector3d(Object3d):
         axis = tuple(range(self.ndim))
         return self.__class__(self.data.mean(axis=axis))
 
-    def to_polar(self) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
+    def to_polar(
+        self, degrees: bool = False
+    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
         r"""Return the azimuth :math:`\phi`, polar :math:`\theta`, and
-        radial :math:`r` spherical coordinates, the angles in radians.
-        The coordinates are defined as in the ISO 31-11 standard
-        :cite:`weisstein2005spherical`.
+        radial :math:`r` spherical coordinates defined as in the ISO
+        31-11 standard :cite:`weisstein2005spherical`.
+
+        Parameters
+        ----------
+        degrees
+            If ``True``, the given angles are returned in degrees.
+            Default is ``False``.
 
         Returns
         -------
         azimuth
-            Azimuth angles.
+            Azimuth angles in radians (``degrees=False``) or degrees
+            (``degrees=True``).
         polar
-            Polar angles.
+            Polar angles in radians (``degrees=False``) or degrees
+            (``degrees=True``).
         radial
             Radial values.
         """
-        return self.azimuth, self.polar, self.radial
+        azimuth = self.azimuth
+        polar = self.polar
+        if degrees:
+            azimuth = np.rad2deg(azimuth)
+            polar = np.rad2deg(polar)
+        return azimuth, polar, self.radial
 
     def in_fundamental_sector(self, symmetry: "Symmetry") -> Vector3d:
         """Project vectors to a symmetry's fundamental sector (inverse
